@@ -1,6 +1,7 @@
 /*
  * Policy routines for the CUPS scheduler.
  *
+ * Copyright © 2020-2024 by OpenPrinting.
  * Copyright 2007-2011, 2014 by Apple Inc.
  * Copyright 1997-2006 by Easy Software Products, all rights reserved.
  *
@@ -116,7 +117,7 @@ cupsdCheckPolicy(cupsd_policy_t *p,	/* I - Policy */
   {
     cupsdLogMessage(CUPSD_LOG_CRIT, "cupsdCheckPolicy: p=%p, con=%p.", p, con);
 
-    return ((http_status_t)0);
+    return (HTTP_STATUS_SERVER_ERROR);
   }
 
  /*
@@ -126,7 +127,7 @@ cupsdCheckPolicy(cupsd_policy_t *p,	/* I - Policy */
   if ((po = cupsdFindPolicyOp(p, con->request->request.op.operation_id)) == NULL)
   {
     cupsdLogMessage(CUPSD_LOG_DEBUG2, "cupsdCheckPolicy: No matching operation, returning 0.");
-    return ((http_status_t)0);
+    return (HTTP_STATUS_OK);
   }
 
   con->best = po;
@@ -270,7 +271,7 @@ cupsdGetPrivateAttrs(
 #ifdef DEBUG
   cupsdLogMessage(CUPSD_LOG_DEBUG2,
                   "cupsdGetPrivateAttrs(policy=%p(%s), con=%p(%d), "
-		  "printer=%p(%s), owner=\"%s\")", policy, policy->name, con,
+		  "printer=%p(%s), owner=\"%s\")", policy, policy ? policy->name : "", con,
 		  con->number, printer, printer ? printer->name : "", owner);
 #endif /* DEBUG */
 
